@@ -215,6 +215,7 @@ def get_filtration(
     valid_columns: Iterable[str],
     *,
     default_filtration_class: type[FiltrationData] = FiltrationData,
+    default_model: Optional[str] = None,
     operator_data: Optional[
         dict[
             str,
@@ -265,10 +266,11 @@ def get_filtration(
                 detail=f"order_by = {order_by!r} is not a valid column. "
                 f"Valid columns: {', '.join(valid_columns)}",
             )
+        parsing_data = parser.parse(request.query_params)
+        if default_model is not None:
+            parsing_data = parsing_data.set_default_model(default_model)
 
-        _kwargs: dict[str, Any] = dict(
-            to_filter=parser.parse(request.query_params), sort_by=sort_by
-        )
+        _kwargs: dict[str, Any] = dict(to_filter=parsing_data, sort_by=sort_by)
         if page_number is not None:
             _kwargs["page_number"] = page_number
         if page_size is not None:
